﻿// Fill out your copyright notice in the Description page of Project Settings.


#include "Player/LMCameraManager.h"

#include "Components/CapsuleComponent.h"
#include "Player/LMMovementComponent.h"
#include "Player/LMPlayer.h"

ALMCameraManager::ALMCameraManager()
{
}

void ALMCameraManager::UpdateViewTarget(FTViewTarget& OutVT, float DeltaTime)
{
	Super::UpdateViewTarget(OutVT, DeltaTime);

	if (ALMPlayer* Player = Cast<ALMPlayer>(GetOwningPlayerController()->GetPawn()))
	{
		ULMMovementComponent* MovementComponent = Player->GetLegumixMovementComponent();
		FVector TargetCrouchOffset = FVector(0, 0,
			MovementComponent->GetCrouchedHalfHeight() - Player->GetClass()->GetDefaultObject<ACharacter>()->GetCapsuleComponent()->GetScaledCapsuleHalfHeight());

		FVector Offset = FMath::Lerp(FVector::ZeroVector, TargetCrouchOffset, FMath::Clamp(CrouchBlendTime / CrouchBlendDuration, 0.f, 1.f));

		if (MovementComponent->IsCrouching())
		{
			CrouchBlendTime = FMath::Clamp(CrouchBlendTime + DeltaTime, 0.f, CrouchBlendDuration);
			Offset -= TargetCrouchOffset;
		}
		else
		{
			CrouchBlendTime = FMath::Clamp(CrouchBlendTime - DeltaTime, 0.f, CrouchBlendDuration);
		}

		if (MovementComponent->IsMovingOnGround())
		{
			OutVT.POV.Location += Offset;
		}
	}
}
